;************************************************************************************************************************************
; Display.inc : Header file for Display/Timer code																					*
;************************************************************************************************************************************

#ifndef __DISPLAY_INC__
#define __DISPLAY_INC__

;************************************************************************************************************************************
; Equ's and Defines																													*
;************************************************************************************************************************************

#Define 	cDisplayDP	    7			;Bit 7 controls DP in display registers 
#Define		cDisplayOff		0x1A		;Display value that turns the segment drivers off
#Define		cDisplayFanBase 0x14		;Constant for displaying Fan1, Base value for other fans
#Define 	cDisplayL		0x10		;Constant for displaying a 'L' (Load)
#Define 	cDisplayS		0x11		;Constant for displaying a 'S' (Store)
#Define		cDisplayI		0x12		;Constant for displaying a 'I'
#Define		cDisplayN		0x13		;Constant for displaying a 'n'
		
;************************************************************************************************************************************
; Imports																															*
;************************************************************************************************************************************

	;Registers
	EXTERN	TimerInt					;Decremented every Timer2 interrupt, stops at 0, for general use, user code is allowed to write to this timer
	EXTERN	TimerSeconds				;Decremented every second, stops at 0, for general use, user code is allowed to write to this timer
	EXTERN	DisplayValue				;The binairy value to be displayed
	EXTERN	DisplayOnes					;The 'Ones' value to be displayed - Bit 7 controls DP
	EXTERN	DisplayTens					;The 'Tens' value to be displayed - Bit 7 controls DP
	EXTERN	DisplayHund					;The 'Hundreds' value to be displayed - Bit 7 controls DP
	EXTERN	DisplayFan					;The 'Fan' value to be displayed - Bit 7 controls DP

	;Functions
	EXTERN	DisplayInit					;Display/Timer Initialisation	
	EXTERN	DisplayISR					;Display/Timer interrupt service routine
	EXTERN	DisplayConvert				;Converts binairy value in "DisplayValue" to decimal in Ones, Tens and Hundreds
	EXTERN	DisplaySetFanW				;Sets the fan display to fan number in W
	EXTERN	DisplaySetTimerSecondsW		;Sets TimerSeconds to the value in W and resets iTimerInt

;************************************************************************************************************************************
; Macros																															*
;************************************************************************************************************************************
; DisplaySetW: Copies the value in W to the specified register while leaving the DP (bit 7) intact. Used to change display values 	*
;		   	   without worrying about DP																							*
;			   Entry -> Bank wich holds register to work on																			*
;			   Exit  -> Bank wich holds register to work on																			*
;************************************************************************************************************************************
DisplaySetW		macro	DisplayRegister

	ANDLW	b'01111111'					;Make sure bit 7 in the W value is cleared
	BTFSC	DisplayRegister, cDisplayDP	;Check if bit 7 is currently set in DisplayRegister
	IORLW	b'10000000'					;If set, then set bit 7 in the W value
	MOVWF	DisplayRegister				;And copy the value to the register	

	Endm

;************************************************************************************************************************************
 
#endif __DISPLAY_INC__
