;************************************************************************************************************************************
; Eeprom.inc : Header file for the internal Eeprom code																				*
; !!!!!!!!!! : Code assumes all RAM addresses to read/write too are in Bank 0 or 1 and that the Eeprom address to read/write too	*
;			   is between 0x00 and 0x3F - Code originally written for the FanBus project on PIC16F870 wich only has 64 bytes of 	*
;			   Eeprom and no RAM in bank 2/3.																						*
; !!!!!!!!!! : The highest Eeprom byte (0x3F) is used for Eeprom validation. Before any write, this byte it set to a non-valid value*
;			   and only after successfull verification is it restored to the valid value (0x5A). A failed verify when writing or 	*
;			   an incorrect validation byte when reading will set the fEepromError flag. This prevents the device from running		*
;			   with incorrectly written eeprom data, caused by an power outage while writing to eeprom, for example					*
;************************************************************************************************************************************

#ifndef __EEPROM_INC__
#define __EEPROM_INC__

;************************************************************************************************************************************
; Equ's and Defines																													*
;************************************************************************************************************************************

#Define	fEepromError		EepromFlags, 0	;Flag indicating an error occured during an Eeprom function	
#Define fEepromWriteBusy	EepromFlags, 1	;Flag indicating an interrupt based write operation is currently in progress

;************************************************************************************************************************************
; Imports																															*
;************************************************************************************************************************************

	;Registers
	EXTERN	EepromAddr					;The eeprom address to read/write too
	EXTERN	EepromRamAddr				;The RAM address to read/write too
	EXTERN	EepromAmount				;The amount of bytes to read/write
	EXTERN	EepromFlags					;Eeprom flags 	

	;Functions
	EXTERN	EepromInit					;Eeprom initialisation - Must be called once before all other Eeprom funtion calls
	EXTERN	EepromRead					;Eeprom Read function
	EXTERN	EepromWrite					;Eeprom Write function
	EXTERN	EepromISR					;Eeprom interrupt service routine

;************************************************************************************************************************************
; Macros																															*
;************************************************************************************************************************************

;...Add macro's here...

;************************************************************************************************************************************
 
#endif __EEPROM_INC__
