;************************************************************************************************************************************
; FanBus.asm: The main code file for the fanbus project, By Busschots Ronny; R.Busschots@skynet.be									*
;************************************************************************************************************************************
	
	#include "General.inc"				;Include project settings
	#include "Display.inc"				;To call display init
	#include "FanSpeed.inc"				;To call FanSpeed init
	#include "PWM.inc"					;For generating PWM cycles
	#include "Interface.inc"			;To run the interface

	__CONFIG 0x3F72						;HS Osc, No WDT, Startup delay, BO	

;************************************************************************************************************************************
; Equ's and Defines																													*
;************************************************************************************************************************************

#Define	EepromReset			1			;Determines if standard eeprom data should be included into the compiled HEX file

;************************************************************************************************************************************
; Eeprom data																														*
;************************************************************************************************************************************

	IF	EepromReset == 1 				;If eeprom data should be included...
	
	ORG	0x2100							;Eeprom address EEADR 0x00
	de	d'100',d'100',d'100'
	de	d'100',d'100',d'100'			;First preset bank - All 6 fans to 100%
	de	d'100',d'100',d'100'
	de 	d'100',d'100',d'100'			;Second preset bank - All 6 fans to 100%
	de 	d'100',d'100',d'100'
	de 	d'100',d'100',d'100'			;Third preset bank - All 6 fans to 100%

	ORG	0x213E							;Eeprom address EEADR 0x3E
	de	0x01							;Preset bank to load on startup: 0x01
	de	0x5A							;Eeprom validation byte: EEPROM data = valid

	ENDIF

;************************************************************************************************************************************
; Exports																															*
;************************************************************************************************************************************

	;Registers
	;...Add register exports here...

	;Functions
	GLOBAL	ISREnd						;Interrupt service routine end, restores context, allows ISR funtions to return with GOTO (saves 1 stack level)

;************************************************************************************************************************************
; Variables																															*
;************************************************************************************************************************************
BankShared		UDATA_SHR				;Uninitialized variables in ALL banks (shared)
W_TEMP			RES 1					;Interrupt context saving: W Reg
STATUS_TEMP		RES 1					;Interrupt context saving: STATUS Reg
PCLATH_TEMP		RES 1					;Interrupt context saving: PCLATH reg
FSR_TEMP		RES 1					;Interrupt context saving: FSR reg

;************************************************************************************************************************************
STARTUP		CODE	;Program entry point on reset																					*
;************************************************************************************************************************************

	GOTO	Main						;Jump to main code

;************************************************************************************************************************************
INTERRUPT	CODE	;Interrupt vector																								*
;************************************************************************************************************************************

	GOTO	ISR							;Jump to interrupt handler in PROG1 code block

;************************************************************************************************************************************
PROG1	CODE		;Code 																											*
;************************************************************************************************************************************
; ISR: Interrupt service routine. Performans context saving, then tests the required interrupt flags and jumps to the correct		*
;	   handler routine accordingly. When done the handler routine returns with a goto to ISREND , wich performs context restore		*																					*
;************************************************************************************************************************************
ISR

	MOVWF	W_TEMP						;Save W Reg
	SWAPF	STATUS, W					;Copy STATUS to W with SWAP instruction, SWAP instruction itself will not influence STATUS
	CLRF	STATUS						;Clear STATUS
	MOVWF	STATUS_TEMP					;Save the swapped copy of STATUS
	MOVF	PCLATH, W			
	MOVWF	PCLATH_TEMP					;Save PCLATH
	CLRF	PCLATH						;Clear PCLATH

	MOVF	FSR, W				
	MOVWF	FSR_TEMP					;Save FSR / IRP Already saved in STATUS_TEMP

	;...Interrupt handler code starts here 

	BANKSEL	PIR1						;Bank 0
	BTFSC	PIR1,  TMR2IF				;Timer 2 interrupt ?
	GOTO	DisplayISR					;Then handle the display ISR

	BTFSC	PIR2, EEIF					;Eeprom interrupt ?
	GOTO	EepromISR					;Then handle the eeprom ISR

	;...Interrupt handler code ends here

ISREnd

	MOVF	FSR_TEMP, W
	MOVWF	FSR							;Restore FSR / IRP Will be restored with STATUS

	MOVF	PCLATH_TEMP, W
	MOVWF	PCLATH						;Restore PCLATH
	SWAPF	STATUS_TEMP, W
	MOVWF	STATUS						;Swap the Swapped copy of STATUS (so its right again) into W and copy to STATUS
	SWAPF	W_TEMP, F			
	SWAPF	W_TEMP, W					;Swap W_Temp into W, because any other instruction would affect STATUS
	RETFIE								;Return from interrupt		
	
;************************************************************************************************************************************
; Main: Main code 																													*
;************************************************************************************************************************************
Main

	BANKSEL	ADCON1						;Bank 1
	MOVLW	0x07
	MOVWF	ADCON1						;Turn off A/D converters, this makes PORTA pins digital IO

	CALL	DisplayInit					;Initialize the display module (Returns in Bank 0)
	CALL	FanSpeedInit				;Initialize the fanspeed module (Returns in Bank 1)
	CALL	PWMInit						;Initialize the PWM module (Returns in Bank 0)
	CALL	InterfaceInit				;Initialize the interface module (Returns in Bank 1)

MainLoop

	CALL	PWMCycle					;Perform a PWM cycle
	CALL	InterfaceTick				;Run the interface
	GOTO	MainLoop					;And repeat forever 

;************************************************************************************************************************************
 
	END		
