;************************************************************************************************************************************
; FanSpeed.inc : Header file for the fan speed management code																		*
;				 The code is designed to handle 3 preset slots																		*
;************************************************************************************************************************************

#ifndef __FANSPEED_INC__
#define __FANSPEED_INC__

	#include "Eeprom.inc"						;For fEepromWriteBusy rename		

;************************************************************************************************************************************
; Equ's and Defines																													*
;************************************************************************************************************************************

#Define	fFanSpeedBusy		fEepromWriteBusy	;Fanspeed code busy flag is the same as the eeprom busy flag
												;NO! Fanspeed functions should be called when this flag is set ! except for FanSpeedErrorTrap
;************************************************************************************************************************************
; Imports																															*
;************************************************************************************************************************************

	;Registers
	EXTERN	FanSpeedValues						;The speed values for every of the 6 fans
	EXTERN	FanSpeedPreset						;Value holding the number of the currently active/loaded preset
	EXTERN	FanSpeedPresetToLoad				;Value holding the number of the preset to load in the FanSpeedLoadPreset function
	EXTERN 	FanSpeedSelectedValue				;The currently selected fanspeed value for manipulation/retrieval	

	;Functions
	EXTERN	FanSpeedInit						;Calls the EepromInit code, then loads the last active slot number + data into ram
	EXTERN	FanSpeedLoadPreset					;Loads the preset slot number in FanSpeedPresetToLoad from eeprom into the FanSpeedValues RAM
	EXTERN	FanSpeedSavePreset					;Saves the current active preset's data from FanSpeedValues into Eeprom
	EXTERN	FanSpeedErrorTrap					;Checks for eeprom errors and traps them - Returns on no error
	EXTERN	FanSpeedSelectLast					;Changes FanSpeedSelectedValue to select Fan 6
	EXTERN	FanSpeedSelectNext					;Changes FanSpeedSelectedValue to select the next fan. Rolls back to Fan 1 after Fan 6
	EXTERN	FanSpeedGetSelectedW				;Retrieves the FanSpeedValue of the fan selected with FanSpeedSelectedValue in W
	EXTERN	FanSpeedDecSelected					;Decreases the FanSpeedValue of the fan selected with FanSpeedSelectedValue
	EXTERN	FanSpeedPresetSelectLast			;Clears FanSpeedPresetToLoad, selecting 'no operation'
	EXTERN	FanSpeedPresetSelectNext			;Changes FanSpeedPresetToLoad to select the next slot for loading (1,2 or 3) /save current (4), rolls back to 0 (nop) after 4

;************************************************************************************************************************************
; Macros																															*
;************************************************************************************************************************************

;...Add Macro's here...

;************************************************************************************************************************************
 
#endif __FANSPEED_INC__
