;************************************************************************************************************************************
; ROMTable.asm : Code file for ROM lookup tables																					*
;************************************************************************************************************************************
	
	#include "General.inc"				;Include project settings

;************************************************************************************************************************************
; Equ's and Defines																													*
;************************************************************************************************************************************

#Define		PointerBank		Bank1		;Defines in wich bank to store the ROM pointer

;************************************************************************************************************************************
; Exports																															*
;************************************************************************************************************************************

	;Registers
	GLOBAL	ROMTableAddr
	GLOBAL	ROMTableAddrH

	;Functions
	GLOBAL	ROMTableGet

;************************************************************************************************************************************
; Variables																															*
;************************************************************************************************************************************
PointerBank		    UDATA  	;Uninitialized variables in "PointerBank"
ROMTableAddr		RES	1	;Low byte of ROM pointer
ROMTableAddrH		RES 1	;High byte of ROM pointer

;************************************************************************************************************************************
PROG1	CODE	;Code 																												*
;************************************************************************************************************************************
; ROMTableGet: Returns the ROMTable byte pointed to by the pointer in W, increments pointer											*
;			   Entry -> Bank X																										*
;			   Exit  -> Bank "PointerBank"																							*
;************************************************************************************************************************************
ROMTableGet

	BANKSEL	ROMTableAddr			;Bank "PointerBank"
	CALL	iDummy					;Call the dummy to throw this adress on the stack
									;RETLW instruction in lookup table will return here with value in W 
	INCF	ROMTableAddr, F			;Increment low byte of pointer
	BTFSC	STATUS, Z				;Overflow ? 
	INCF	ROMTableAddrH, F		;yes ? then also increment the high byte
	
	RETURN							;Return with the retrieved byte in W

;************************************************************************************************************************************
; iDummy: Dummy function that will perform a GOTO to the ROM address in pointer - The RETLW instruction in the table will return	*
;		  to this functions caller.																									*
;		  Entry -> "PointerBank"																									*
;		  Exit  -> "PointerBank"																									*
;************************************************************************************************************************************
iDummy

	MOVF	ROMTableAddrH, W
	MOVWF	PCLATH					;copy high byte of address to PCLATH - This won't perform a GOTO yet !
	MOVF	ROMTableAddr, W
	MOVWF	PCL						;copy low byte of address to PCL - This will perform a GOTO to RomTableAddrH:RomTableAddrL
			
;************************************************************************************************************************************
 
	END		
